@@ -1,4 +1,4 @@
-#!/usr/bin/python2.7
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 """ 
@@ -6,17 +6,17 @@ Mesh Subdivision Plugin.
 
 **Project Name:**      MakeHuman
 
-**Product Home Page:** http://www.makehuman.org/
+**Product Home Page:** http://www.makehumancommunity.org/
 
-**Code Home Page:**    https://bitbucket.org/MakeHuman/makehuman/
+**Github Code Home Page:**    https://github.com/makehumancommunity/
 
 **Authors:**           Marc Flerackers, Glynn Clements
 
-**Copyright(c):**      MakeHuman Team 2001-2017
+**Copyright(c):**      MakeHuman Team 2001-2020
 
 **Licensing:**         AGPL3
 
-    This file is part of MakeHuman (www.makehuman.org).
+    This file is part of MakeHuman Community (www.makehumancommunity.org).
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -60,6 +60,7 @@ class SubdivisionObject(Object3D):
 
         self.MAX_FACES = object.MAX_FACES
         self.cameraMode = object.cameraMode
+        self.vertsPerFaceForExport = object.vertsPerFaceForExport
         self.visibility = object.visibility
         self.pickable = object.pickable
         self.transparentPrimitives = object.transparentPrimitives * 4
@@ -148,7 +149,7 @@ class SubdivisionObject(Object3D):
 
         _, x0 = np.unique(fvedges2, return_index=True)
         _, x1 = np.unique(fvedges2[::-1], return_index=True)
-        xmap = np.hstack((x0[:,None]/4, len(fvedges2) - 1 - x1[:,None]/4))
+        xmap = np.hstack((x0[:,None]//4, len(fvedges2) - 1 - x1[:,None]//4))
         vedgelist = np.hstack((vedgelist, xmap)).reshape((-1,2,2))
         del xmap
 
@@ -225,7 +226,7 @@ class SubdivisionObject(Object3D):
         n = np.hstack((n, np.array([len(vi) - first[-1]])))
         self.nedges[ix] = n.astype(np.uint8)
         try:
-            for i in xrange(len(ix)):
+            for i in range(len(ix)):
                 self.vedge[ix[i],:n[i]] = ei[first[i]:][:n[i]]
         except ValueError as e:
             raise RuntimeError("Pole-count too low, try increasing max_pole: %s" % e)
@@ -503,11 +504,23 @@ def _reverse_n_to_m_map(input, output, offset=0):
     n = first[1:] - first[:-1]
     n_last = len(vi) - first[-1]
     n = np.hstack((n, np.array([n_last])))
-    for i in xrange(len(ix)):
+    for i in range(len(ix)):
         output[ix[i], :n[i]] = offset + fi[first[i]:][:n[i]]
 
 
 def createSubdivisionObject(object, staticFaceMask=None):
+    #
+    # since the algorithm was written for quads we avoid triangle-meshes to be subdivided
+    # and return the object given
+    #
+    if object.vertsPerFaceForExport != 4:
+        log.debug('No Catmull-Clark subdivision on triangle-mesh %s.', object.name)
+        return object
+
+    if len(object.texco) == 0:
+        log.debug('No Catmull-Clark subdivision on mesh %s without UV map.', object.name)
+        return object
+
     obj = SubdivisionObject(object, staticFaceMask)
     obj.create()
     return obj
