@@ -1,20 +1,20 @@
-#!/usr/bin/python2.7
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 """
 **Project Name:**      MakeHuman
 
-**Product Home Page:** http://www.makehuman.org/
+**Product Home Page:** http://www.makehumancommunity.org/
 
-**Code Home Page:**    https://bitbucket.org/MakeHuman/makehuman/
+**Github Code Home Page:**    https://github.com/makehumancommunity/
 
 **Authors:**           Jonas Hauquier
 
-**Copyright(c):**      MakeHuman Team 2001-2017
+**Copyright(c):**      MakeHuman Team 2001-2020
 
 **Licensing:**         AGPL3
 
-    This file is part of MakeHuman (www.makehuman.org).
+    This file is part of MakeHuman Community (www.makehumancommunity.org).
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -138,12 +138,12 @@ class ProxyChooserTaskView(gui3d.TaskView, filecache.MetadataCacher):
             if not os.path.isfile(clearIcon):
                 clearIcon = getpath.getSysDataPath('clear.thumb')
 
-        self.filechooser = fc.IconListFileChooser(self.paths, self.getFileExtension(), 'thumb', notfoundIcon, clearIcon, name=self.label, multiSelect=self.multiProxy, noneItem = not self.multiProxy)
+        self.filechooser = fc.IconListFileChooser(self.paths, self.getFileExtension(), 'thumb', notfoundIcon, clearIcon, name=self.label, multiSelect=self.multiProxy, noneItem = not self.multiProxy, stickyTags=gui3d.app.getSetting('makehumanTags'))
         self.addRightWidget(self.filechooser)
 
         self.filechooser.setIconSize(50,50)
         self.filechooser.enableAutoRefresh(False)
-        if not isinstance(self.getFileExtension(), basestring) and \
+        if not isinstance(self.getFileExtension(), str) and \
            len(self.getFileExtension()) > 1:
             self.filechooser.mutexExtensions = True
         #self.addLeftWidget(self.filechooser.createSortBox())
@@ -155,7 +155,7 @@ class ProxyChooserTaskView(gui3d.TaskView, filecache.MetadataCacher):
         if self.descriptionWidget:
             descBox = self.addLeftWidget(gui.GroupBox('Description'))
             self.descrLbl = descBox.addWidget(gui.TextView(''))
-            self.descrLbl.setSizePolicy(gui.QtGui.QSizePolicy.Ignored, gui.QtGui.QSizePolicy.Preferred)
+            self.descrLbl.setSizePolicy(gui.QtWidgets.QSizePolicy.Ignored, gui.QtWidgets.QSizePolicy.Preferred)
             self.descrLbl.setWordWrap(True)
 
         @self.filechooser.mhEvent
@@ -306,11 +306,12 @@ class ProxyChooserTaskView(gui3d.TaskView, filecache.MetadataCacher):
             self.deselectProxy(None, suppressSignal = True)
 
         mesh,obj = pxy.loadMeshAndObject(human)
-        mesh.setPickable(True)  # Allow mouse picking for proxies attached to human
         
         if not mesh:
             return
 
+        mesh.setPickable(True)  # Allow mouse picking for proxies attached to human
+
         gui3d.app.addObject(obj)
 
         self.filechooser.selectItem(mhclofile)
@@ -339,7 +340,7 @@ class ProxyChooserTaskView(gui3d.TaskView, filecache.MetadataCacher):
         """
         if self.multiProxy:
             idx = self._getProxyIndex(mhclofile)
-            if idx == None:
+            if idx is None:
                 return
         else:
             if self.isProxySelected():
@@ -381,7 +382,7 @@ class ProxyChooserTaskView(gui3d.TaskView, filecache.MetadataCacher):
         contain multiple entries, if this is library allows selecting only a
         single proxy, the list is either of length 0 or 1.
         """
-        return list(self.selectedProxies)
+        return self.selectedProxies
 
     def getObjects(self):
         """
