@@ -1,20 +1,20 @@
-#!/usr/bin/python2.7
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 """
 **Project Name:**      MakeHuman
 
-**Product Home Page:** http://www.makehuman.org/
+**Product Home Page:** http://www.makehumancommunity.org/
 
-**Code Home Page:**    https://bitbucket.org/MakeHuman/makehuman/
+**Github Code Home Page:**    https://github.com/makehumancommunity/
 
 **Authors:**           Marc Flerackers, Glynn Clements, Jonas Hauquier
 
-**Copyright(c):**      MakeHuman Team 2001-2017
+**Copyright(c):**      MakeHuman Team 2001-2020
 
 **Licensing:**         AGPL3
 
-    This file is part of MakeHuman (www.makehuman.org).
+    This file is part of MakeHuman Community (www.makehumancommunity.org).
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -46,6 +46,7 @@ import operator
 import numpy as np
 import log
 import targets
+from functools import reduce
 
 
 # Gender
@@ -444,7 +445,7 @@ class ManagedTargetModifier(Modifier):
         path = tuple(path.split('-'))
         for target in targets.getTargets().groups.get(path, []):
             keys = [key
-                    for key, var in target.data.iteritems()
+                    for key, var in target.data.items()
                     if var is not None]
             result.update(keys)
         return result
@@ -672,7 +673,7 @@ def loadModifiers(filename, human):
     from collections import OrderedDict
     modifiers = []
     lookup = OrderedDict()
-    data = json.load(open(filename, 'rb'), object_pairs_hook=OrderedDict)
+    data = json.load(open(filename, 'r', encoding='utf-8'), object_pairs_hook=OrderedDict)
     for modifierGroup in data:
         groupName = modifierGroup['group']
         for mDef in modifierGroup['modifiers']:
@@ -706,7 +707,7 @@ def loadModifiers(filename, human):
     descFile = _tmp[0]+'_desc'+_tmp[1]
     hasDesc = OrderedDict([(key,False) for key in lookup.keys()])
     if os.path.isfile(descFile):
-        data = json.load(open(descFile, 'rb'), object_pairs_hook=OrderedDict)
+        data = json.load(open(descFile, 'r', encoding='utf-8'), object_pairs_hook=OrderedDict)
         dCount = 0
         for mName, mDesc in data.items():
             try:
@@ -722,4 +723,3 @@ def loadModifiers(filename, human):
             log.warning("No description defined for modifier %s!", mName)
 
     return modifiers
-
