@@ -231,6 +231,7 @@ class MHApplication(gui3d.Application, mh.Application):
                 'units': 'metric',
                 'real_weight': False,
                 'guiTheme': 'makehuman',
+                'sliderEditWidgetVisibility': False,
                 'restoreWindowSize': True,
                 'windowGeometry': '',
                 'useHDPI': False,
@@ -265,6 +266,7 @@ class MHApplication(gui3d.Application, mh.Application):
                 'rtl': False,
                 'sliderImages': True,
                 'guiTheme': 'makehuman',
+                'sliderEditWidgetVisibility': False,
                 'preloadTargets': False,
                 'restoreWindowSize': True,
                 'windowGeometry': '',
@@ -791,6 +793,10 @@ class MHApplication(gui3d.Application, mh.Application):
             self.setTheme(self.getSetting('guiTheme'))
         except:
             self.setTheme("default")
+        try:
+            self.setSliderEditWidgetVisibility(self.getSetting('sliderEditWidgetVisibility'))
+        except:
+            self.setSliderEditWidgetVisibility(False)
 
         progress.step('Applying targets')
         self.loadFinish()
@@ -1031,6 +1037,12 @@ class MHApplication(gui3d.Application, mh.Application):
             if promptOnFail:
                 self.prompt('Error', 'Could not save settings file.', 'OK')
 
+    def setSliderEditWidgetVisibility(self, isVisible):
+        for widget in self.allWidgets():
+            if isinstance(widget, gui.Slider):
+                widget.setEditWidgetVisibility(isVisible)
+
+
     # Themes
     def setTheme(self, theme):
         # Disabling this check allows faster testing of a skin by reloading it.
@@ -1237,14 +1249,21 @@ class MHApplication(gui3d.Application, mh.Application):
         """
         Show about dialog
         """
-        #gui.QtGui.QMessageBox.about(self.mainwin, 'About MakeHuman', mh.getCopyrightMessage())
-        #aboutbox = gui.AboutBox(self.mainwin, 'About MakeHuman', mh.getCopyrightMessage())
-        abouttext = '<h1>MakeHuman license</h1>' + mh.getCopyrightMessage() + "\n" + mh.getCredits(richtext=True) + "\n\n" + mh.getSoftwareLicense(richtext=True) + "\n\n\n" + mh.getThirdPartyLicenses(richtext=True)
+        abouttext = '<h1>MakeHuman license</h1>' + mh.getCopyrightMessage() + "\n\n" + mh.getSoftwareLicense(richtext=True) + "\n\n\n" + mh.getThirdPartyLicenses(richtext=True)
 
         aboutbox = gui.AboutBoxScrollbars(self.mainwin, 'About MakeHuman', abouttext, "MakeHuman v"+mh.getVersionStr(verbose=False, full=True))
         aboutbox.show()
         aboutbox.exec_()
 
+    def credits(self):
+        """
+        Show credits dialog
+        """
+        abouttext = '<h1>MakeHuman credits</h1>' + mh.getCredits(richtext=True) + "\n\n"
+        aboutbox = gui.AboutBoxScrollbars(self.mainwin, 'Credits', abouttext, "MakeHuman v"+mh.getVersionStr(verbose=False, full=True))
+        aboutbox.show()
+        aboutbox.exec_()
+
     def setGlobalCamera(self):
         human = self.selectedHuman
 
