@@ -72,13 +72,13 @@ class FileCache(object):
     def getMetadata(self, filename):
         """Retrieve a metadata entry from this cache"""
         fileId = getpath.canonicalPath(filename)
-        return self[fileId]
+        return self._cache.get(fileId)
 
     def cleanup(self):
         """
         Remove non-existing entries from this cache
         """
-        for fileId in list(self._cache.keys()):
+        for fileId in self._cache.keys():
             if not os.path.exists(fileId):
                 try:
                     del self._cache[fileId]
@@ -149,7 +149,11 @@ class FileCache(object):
                 if not (mtime > cached_mtime):
                     continue
 
-            self._cache[fileId] = (mtime,) + getMetadata(filepath)
+            try:
+                self._cache[fileId] = (mtime,) + getMetadata(filepath)
+            except Exception as e:
+                log.error('Error while parsing metadata for file ', str(e))
+                log.error('Failed to parse metadata for file ', filepath)
 
         if removeOldEntries:
             """Remove entries from cache that no longer exist"""
