@@ -1,20 +1,20 @@
-#!/usr/bin/python2.7
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 """ 
 **Project Name:**      MakeHuman
 
-**Product Home Page:** http://www.makehuman.org/
+**Product Home Page:** http://www.makehumancommunity.org/
 
-**Code Home Page:**    https://bitbucket.org/MakeHuman/makehuman/
+**Github Code Home Page:**    https://github.com/makehumancommunity/
 
 **Authors:**           Glynn Clements, Jonas Hauquier
 
-**Copyright(c):**      MakeHuman Team 2001-2017
+**Copyright(c):**      MakeHuman Team 2001-2020
 
 **Licensing:**         AGPL3
 
-    This file is part of MakeHuman (www.makehuman.org).
+    This file is part of MakeHuman Community (www.makehumancommunity.org).
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -35,11 +35,16 @@ Abstract
 
 TODO
 """
+
+from __future__ import division
 from core import G
 
 import numpy as np
 
+from typing import Callable, List
+
 import OpenGL
+import OpenGL.GLU
 OpenGL.ERROR_CHECKING = G.args.get('debugopengl', False)
 OpenGL.ERROR_LOGGING = G.args.get('debugopengl', False)
 OpenGL.FULL_LOGGING = G.args.get('fullloggingopengl', False)
@@ -63,6 +68,16 @@ g_primitiveMap = [GL_POINTS, GL_LINES, GL_TRIANGLES, GL_QUADS]
 TEX_NOT_FOUND = False
 MAX_TEXTURE_UNITS = 0
 
+#TODO: Investigate possibility of decreasing performance impact. Better name?
+def safeRun(func: Callable, *args, fallbacks: List[Callable] = None, **kwargs):
+    try:
+        return func(*args, **kwargs)
+    except Exception as error:
+        log.error(f"{func.__name__} raised {error}")
+        for fallback in fallbacks or []:
+            return fallback(*args, **kwargs)
+
+
 def grabScreen(x, y, width, height, filename = None, productionRender=False):
     if width <= 0 or height <= 0:
         raise RuntimeError("width or height is 0")
@@ -96,8 +111,8 @@ def grabScreen(x, y, width, height, filename = None, productionRender=False):
     if width != rwidth or height != rheight:
         surf = np.zeros((height, width, 3), dtype = np.uint8) + 127
         surf[...] = surface[:1,:1,:]
-        dx0 = (width - rwidth) / 2
-        dy0 = (height - rheight) / 2
+        dx0 = (width - rwidth) // 2
+        dy0 = (height - rheight) // 2
         dx1 = dx0 + rwidth
         dy1 = dy0 + rheight
         surf[dy0:dy1,dx0:dx1] = surface
@@ -118,7 +133,7 @@ pickingBufferDirty = True
 def updatePickingBuffer():
     width = G.windowWidth
     height = G.windowHeight
-    rwidth = (width + 3) / 4 * 4
+    rwidth = (width + 3) // 4 * 4
 
     # Resize the buffer in case the window size has changed
     global pickingBuffer
@@ -226,7 +241,7 @@ def reshape(w, h):
         glMatrixMode(GL_MODELVIEW)
 
         updatePickingBuffer()
-    except StandardError:
+    except Exception:
         log.error('gl.reshape', exc_info=True)
 
 def getMousePos():
@@ -267,15 +282,16 @@ def OnInit():
         # Start with writing relevant info to the debug dump in case stuff goes
         # wrong at a later time
         debugdump.dump.appendGL()
-        debugdump.dump.appendMessage("GL.VENDOR: " + glGetString(GL_VENDOR))
-        debugdump.dump.appendMessage("GL.RENDERER: " + glGetString(GL_RENDERER))
-        debugdump.dump.appendMessage("GL.VERSION: " + glGetString(GL_VERSION))
-        debugdump.dump.appendMessage("GLSL.VERSION: " + Shader.glslVersionStr())
+        debugdump.dump.appendMessage("GL.VENDOR: " + str(glGetString(GL_VENDOR), encoding='UTF-8'))
+        debugdump.dump.appendMessage("GL.RENDERER: " + str(glGetString(GL_RENDERER), encoding='UTF-8'))
+        debugdump.dump.appendMessage("GL.VERSION: " + str(glGetString(GL_VERSION), encoding='UTF-8'))
+        debugdump.dump.appendMessage("GLSL.VERSION: " + str(Shader.glslVersionStr(), encoding='UTF-8'))
+
     except Exception as e:
         log.error("Failed to write GL debug info to debug dump: %s", format(str(e)))
 
     global have_multisample
-    if G.args.get('nomultisampling', False):
+    if not G.args.get('multisampling', False):
         have_multisample = False
     else:
         have_multisample = glInitMultisampleARB()
@@ -433,21 +449,21 @@ def drawMesh(obj):
             else:
                 glBindTexture(GL_TEXTURE_2D, TEX_NOT_FOUND.textureId)
             if have_activeTexture:
-                for gl_tex_idx in xrange(GL_TEXTURE0 + 1, GL_TEXTURE0 + MAX_TEXTURE_UNITS):
+                for gl_tex_idx in range(GL_TEXTURE0 + 1, GL_TEXTURE0 + MAX_TEXTURE_UNITS):
                     glActiveTexture(gl_tex_idx)
                     glBindTexture(GL_TEXTURE_2D, 0)
-                    glDisable(GL_TEXTURE_2D)
+                    #glDisable(GL_TEXTURE_2D)
                     glBindTexture(GL_TEXTURE_1D, 0)
-                    glDisable(GL_TEXTURE_1D)
+                    #glDisable(GL_TEXTURE_1D)
         else:
             # Disable all textures (when in fixed function textureless shading mode)
-            for gl_tex_idx in xrange(GL_TEXTURE0, GL_TEXTURE0 + MAX_TEXTURE_UNITS):
+            for gl_tex_idx in range(GL_TEXTURE0, GL_TEXTURE0 + MAX_TEXTURE_UNITS):
                 if have_activeTexture:
                     glActiveTexture(gl_tex_idx)
                 glBindTexture(GL_TEXTURE_2D, 0)
-                glDisable(GL_TEXTURE_2D)
+                #glDisable(GL_TEXTURE_2D)
                 glBindTexture(GL_TEXTURE_1D, 0)
-                glDisable(GL_TEXTURE_1D)
+                #glDisable(GL_TEXTURE_1D)
 
     if obj.nTransparentPrimitives:
         # TODO not needed for alpha-to-coverage rendering (it's face order independent)
@@ -613,6 +629,7 @@ def drawMesh(obj):
 
     glColorMaterial(GL_FRONT, GL_DIFFUSE)
 
+    # TODO: consider whether this is going to cause a crash on AMD cards. It's possible it should be commented out.
     if obj.isTextured and obj.texture and obj.solid:
         glDisable(GL_TEXTURE_2D)
 
@@ -705,10 +722,10 @@ def renderSkin(dst, vertsPerPrimitive, verts, index = None, objectMatrix = None,
 
     width, height = dst.width, dst.height
 
-    framebuffer = glGenFramebuffers(1)
-    glBindFramebuffer(GL_FRAMEBUFFER, framebuffer)
-    glFramebufferTexture2D(GL_DRAW_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, dst.textureId, 0)
-    glFramebufferTexture2D(GL_READ_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, dst.textureId, 0)
+    framebuffer = safeRun(glGenFramebuffers, 1, fallbacks=(glGenFramebuffersEXT))
+    safeRun(glBindFramebuffer, GL_FRAMEBUFFER, framebuffer, fallbacks=(glBindFramebufferEXT))
+    safeRun(glFramebufferTexture2D, GL_DRAW_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, dst.textureId, 0, fallbacks=(glFramebufferTexture2DEXT))
+    safeRun(glFramebufferTexture2D, GL_READ_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, dst.textureId, 0, fallbacks=(glFramebufferTexture2DEXT))
 
     if clearColor is not None:
         glClearColor(clearColor[0], clearColor[1], clearColor[2], clearColor[3])
@@ -787,17 +804,19 @@ def renderSkin(dst, vertsPerPrimitive, verts, index = None, objectMatrix = None,
 
     glEnableClientState(GL_COLOR_ARRAY)
 
+    # TODO: consider whether this is going to cause a crash on AMD cards. It's possible it should be commented out.
     glDisable(GL_TEXTURE_2D)
+
     glDisableClientState(GL_TEXTURE_COORD_ARRAY)
 
     surface = np.empty((height, width, 4), dtype = np.uint8)
     glReadPixels(0, 0, width, height, GL_RGBA, GL_UNSIGNED_BYTE, surface)
     surface = Image(data = np.ascontiguousarray(surface[::-1,:,:3]))
 
-    glFramebufferTexture2D(GL_DRAW_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, 0, 0)
-    glFramebufferTexture2D(GL_READ_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, 0, 0)
-    glBindFramebuffer(GL_FRAMEBUFFER, 0)
-    glDeleteFramebuffers(np.array([framebuffer]))
+    safeRun(glFramebufferTexture2D, GL_DRAW_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, 0, 0, fallbacks=(glFramebufferTexture2DEXT))
+    safeRun(glFramebufferTexture2D, GL_READ_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, 0, 0, fallbacks=(glFramebufferTexture2DEXT))
+    safeRun(glBindFramebuffer, GL_FRAMEBUFFER, 0, fallbacks=(glBindFramebufferEXT))
+    safeRun(glDeleteFramebuffers, np.array([framebuffer]), fallbacks=(glDeleteFramebuffersEXT))
     glBindTexture(GL_TEXTURE_2D, 0)
 
     return surface
@@ -809,9 +828,9 @@ def renderToBuffer(width, height, productionRender = True):
     hasRenderToRenderbuffer().
     """
     # Create and bind framebuffer
-    framebuffer = glGenFramebuffers(1)
+    framebuffer = safeRun(glGenFramebuffers, 1, fallbacks=(glGenFramebuffersEXT))
     #glBindFramebuffer(GL_DRAW_FRAMEBUFFER, framebuffer)
-    glBindFramebuffer(GL_FRAMEBUFFER, framebuffer)
+    safeRun(glBindFramebuffer, GL_FRAMEBUFFER, framebuffer, fallbacks=(glBindFramebufferEXT))
 
     # Now that framebuffer is bound, verify whether dimensions are within max supported dimensions
     maxWidth, maxHeight = glGetInteger(GL_MAX_VIEWPORT_DIMS)
@@ -825,22 +844,22 @@ def renderToBuffer(width, height, productionRender = True):
         width = int(height / aspect)
 
     # Create and bind renderbuffers
-    renderbuffer = glGenRenderbuffers(1)    # We need a renderbuffer for both color and depth
-    depthRenderbuffer = glGenRenderbuffers(1)
-    glBindRenderbuffer(GL_RENDERBUFFER, renderbuffer)
+    renderbuffer = safeRun(glGenRenderbuffers, 1, fallbacks=(glGenRenderbuffersEXT))    # We need a renderbuffer for both color and depth
+    depthRenderbuffer = safeRun(glGenRenderbuffers, 1, fallbacks=(glGenRenderbuffersEXT))
+    safeRun(glBindRenderbuffer, GL_RENDERBUFFER, renderbuffer, fallbacks=(glBindRenderbufferEXT))
     global have_multisample
     if have_multisample:
-        glRenderbufferStorageMultisample(GL_RENDERBUFFER, 4, GL_RGBA, width, height)
+        safeRun(glRenderbufferStorageMultisample, GL_RENDERBUFFER, 4, GL_RGBA, width, height, fallbacks=(glRenderbufferStorageMultisampleEXT))
     else:
-        glRenderbufferStorage(GL_RENDERBUFFER, GL_RGBA, width, height)
-    glFramebufferRenderbuffer(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_RENDERBUFFER, renderbuffer)
+        safeRun(glRenderbufferStorage, GL_RENDERBUFFER, GL_RGBA, width, height, fallbacks=(glRenderbufferStorageEXT))
+    safeRun(glFramebufferRenderbuffer, GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_RENDERBUFFER, renderbuffer, fallbacks=(glFramebufferRenderbufferEXT))
 
-    glBindRenderbuffer(GL_RENDERBUFFER, depthRenderbuffer)
+    safeRun(glBindRenderbuffer, GL_RENDERBUFFER, depthRenderbuffer, fallbacks=(glBindRenderbufferEXT))
     if have_multisample:
-        glRenderbufferStorageMultisample(GL_RENDERBUFFER, 4, GL_DEPTH_COMPONENT16, width, height)
+        safeRun(glRenderbufferStorageMultisample, GL_RENDERBUFFER, 4, GL_DEPTH_COMPONENT16, width, height, fallbacks=(glRenderbufferStorageMultisampleEXT))
     else:
-        glRenderbufferStorage(GL_RENDERBUFFER, GL_DEPTH_COMPONENT16, width, height)
-    glFramebufferRenderbuffer(GL_FRAMEBUFFER, GL_DEPTH_ATTACHMENT, GL_RENDERBUFFER, depthRenderbuffer)
+        safeRun(glRenderbufferStorage, GL_RENDERBUFFER, GL_DEPTH_COMPONENT16, width, height, fallbacks=(glRenderbufferStorageEXT))
+    safeRun(glFramebufferRenderbuffer, GL_FRAMEBUFFER, GL_DEPTH_ATTACHMENT, GL_RENDERBUFFER, depthRenderbuffer, fallbacks=(glFramebufferRenderbufferEXT))
 
     # TODO check with glCheckFramebufferStatus ?
     if not glCheckFramebufferStatus(GL_FRAMEBUFFER):
@@ -865,42 +884,43 @@ def renderToBuffer(width, height, productionRender = True):
 
     if have_multisample:
         # If we have drawn to a multisample renderbuffer, we need to transfer it to a simple buffer to read it
-        downsampledFramebuffer = glGenFramebuffers(1)
-        glBindFramebuffer(GL_READ_FRAMEBUFFER, framebuffer)       # Multisampled FBO
-        glBindFramebuffer(GL_DRAW_FRAMEBUFFER, downsampledFramebuffer) # Regular FBO
-        regularRenderbuffer = glGenRenderbuffers(1)
-        glBindRenderbuffer(GL_RENDERBUFFER, regularRenderbuffer)
-        glRenderbufferStorage(GL_RENDERBUFFER, GL_RGBA, width, height)
-        glFramebufferRenderbuffer(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_RENDERBUFFER, regularRenderbuffer)
+        downsampledFramebuffer = safeRun(glGenFramebuffers, 1, fallbacks=(glGenFramebuffersEXT))
+        safeRun(glBindFramebuffer, GL_READ_FRAMEBUFFER, framebuffer, fallbacks=(glBindFramebufferEXT))       # Multisampled FBO
+        safeRun(glBindFramebuffer, GL_DRAW_FRAMEBUFFER, downsampledFramebuffer, fallbacks=(glBindFramebufferEXT)) # Regular FBO
+        regularRenderbuffer = safeRun(glGenRenderbuffers, 1, fallbacks=(glGenRenderbuffersEXT)) 
+        safeRun(glBindRenderbuffer, GL_RENDERBUFFER, regularRenderbuffer, fallbacks=(glBindRenderbufferEXT))
+        safeRun(glRenderbufferStorage, GL_RENDERBUFFER, GL_RGBA, width, height, fallbacks=(glRenderbufferStorageEXT))
+        safeRun(glFramebufferRenderbuffer, GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_RENDERBUFFER, regularRenderbuffer, fallbacks=(glFramebufferRenderbufferEXT))
         glBlitFramebuffer(0, 0, width, height, 0, 0, width, height, GL_COLOR_BUFFER_BIT, GL_NEAREST)
 
         # Dealloc what we no longer need
-        glDeleteFramebuffers(np.array([framebuffer]))
+        safeRun(glDeleteFramebuffers, np.array([framebuffer]), fallbacks=(glDeleteFramebuffersEXT))
         framebuffer = downsampledFramebuffer
         del downsampledFramebuffer
-        glDeleteRenderbuffers(1, np.array([renderbuffer]))
+        safeRun(glDeleteRenderbuffers, 1, np.array([renderbuffer]), fallbacks=(glDeleteRenderbuffersEXT))
         renderbuffer = regularRenderbuffer
         del regularRenderbuffer
 
     # Read pixels
     surface = np.empty((height, width, 4), dtype = np.uint8)
-    glBindFramebuffer(GL_FRAMEBUFFER, framebuffer)
+    safeRun(glBindFramebuffer, GL_FRAMEBUFFER, framebuffer, fallbacks=(glBindFramebufferEXT))
     glReadBuffer(GL_COLOR_ATTACHMENT0)
     glReadPixels(0, 0, width, height, GL_RGBA, GL_UNSIGNED_BYTE, surface)
 
     surface = Image(data = np.ascontiguousarray(surface[::-1,:,[2,1,0]]))
 
     # Unbind frame buffer
-    glDeleteFramebuffers(np.array([framebuffer]))
-    glDeleteRenderbuffers(1, np.array([renderbuffer]))
-    glDeleteRenderbuffers(1, np.array([depthRenderbuffer]))
-    glBindRenderbuffer(GL_RENDERBUFFER, 0)
-    glBindFramebuffer(GL_FRAMEBUFFER, 0)
+    safeRun(glDeleteFramebuffers, np.array([framebuffer]), fallbacks=(glDeleteFramebuffersEXT))
+    safeRun(glDeleteRenderbuffers, 1, np.array([renderbuffer]), fallbacks=(glDeleteRenderbuffersEXT))
+    safeRun(glDeleteRenderbuffers, 1, np.array([depthRenderbuffer]), fallbacks=(glDeleteRenderbuffersEXT))
+    safeRun(glBindRenderbuffer, GL_RENDERBUFFER, 0, fallbacks=(glBindRenderbufferEXT))
+    safeRun(glBindFramebuffer, GL_FRAMEBUFFER, 0, fallbacks=(glBindFramebufferEXT))
 
     # Restore viewport dimensions to those of the window
     G.windowWidth = oldWidth
     G.windowHeight = oldHeight
-    glPushAttrib(GL_VIEWPORT_BIT)
+    # glPushAttrib(GL_VIEWPORT_BIT)
+    glPopAttrib()
     glViewport(0, 0, oldWidth, oldHeight)
 
     return surface
@@ -913,8 +933,8 @@ def renderAlphaMask(width, height, productionRender = True):
     hasRenderToRenderbuffer().
     """
     # Create and bind framebuffer
-    framebuffer = glGenFramebuffers(1)
-    glBindFramebuffer(GL_FRAMEBUFFER, framebuffer)
+    framebuffer = safeRun(glGenFramebuffers, 1, fallbacks=(glGenFramebuffersEXT))
+    safeRun(glBindFramebuffer, GL_FRAMEBUFFER, framebuffer, fallbacks=(glBindFramebufferEXT))
 
     # Now that framebuffer is bound, verify whether dimensions are within max supported dimensions
     maxWidth, maxHeight = glGetInteger(GL_MAX_VIEWPORT_DIMS)
@@ -922,15 +942,15 @@ def renderAlphaMask(width, height, productionRender = True):
     height = min(height, maxHeight)
 
     # Create and bind renderbuffers
-    renderbuffer = glGenRenderbuffers(1)    # We need a renderbuffer for both color and depth
-    depthRenderbuffer = glGenRenderbuffers(1)
-    glBindRenderbuffer(GL_RENDERBUFFER, renderbuffer)
-    glRenderbufferStorage(GL_RENDERBUFFER, GL_RGBA, width, height)
-    glFramebufferRenderbuffer(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_RENDERBUFFER, renderbuffer)
+    renderbuffer = safeRun(glGenRenderbuffers, 1, fallbacks=(glGenRenderbuffersEXT))     # We need a renderbuffer for both color and depth
+    depthRenderbuffer = safeRun(glGenRenderbuffers, 1, fallbacks=(glGenRenderbuffersEXT)) 
+    safeRun(glBindRenderbuffer, GL_RENDERBUFFER, renderbuffer, fallbacks=(glBindRenderbufferEXT))
+    safeRun(glRenderbufferStorage, GL_RENDERBUFFER, GL_RGBA, width, height, fallbacks=(glRenderbufferStorageEXT))
+    safeRun(glFramebufferRenderbuffer, GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_RENDERBUFFER, renderbuffer, fallbacks=(glFramebufferRenderbufferEXT))
 
-    glBindRenderbuffer(GL_RENDERBUFFER, depthRenderbuffer)
-    glRenderbufferStorage(GL_RENDERBUFFER, GL_DEPTH_COMPONENT16, width, height)
-    glFramebufferRenderbuffer(GL_FRAMEBUFFER, GL_DEPTH_ATTACHMENT, GL_RENDERBUFFER, depthRenderbuffer)
+    safeRun(glBindRenderbuffer, GL_RENDERBUFFER, depthRenderbuffer, fallbacks=(glBindRenderbufferEXT))
+    safeRun(glRenderbufferStorage, GL_RENDERBUFFER, GL_DEPTH_COMPONENT16, width, height, fallbacks=(glRenderbufferStorageEXT))
+    safeRun(glFramebufferRenderbuffer, GL_FRAMEBUFFER, GL_DEPTH_ATTACHMENT, GL_RENDERBUFFER, depthRenderbuffer, fallbacks=(glFramebufferRenderbufferEXT))
 
     # TODO check with glCheckFramebufferStatus ?
     if not glCheckFramebufferStatus(GL_FRAMEBUFFER):
@@ -964,7 +984,7 @@ def renderAlphaMask(width, height, productionRender = True):
 
     # Read pixels
     surface = np.empty((height, width, 4), dtype = np.uint8)
-    glBindFramebuffer(GL_FRAMEBUFFER, framebuffer)
+    safeRun(glBindFramebuffer, GL_FRAMEBUFFER, framebuffer, fallbacks=(glBindFramebufferEXT))
     glReadBuffer(GL_COLOR_ATTACHMENT0)
     glReadPixels(0, 0, width, height, GL_RGBA, GL_UNSIGNED_BYTE, surface)
 
@@ -972,16 +992,17 @@ def renderAlphaMask(width, height, productionRender = True):
     surface = Image(data = np.ascontiguousarray(surface[::-1,:,[3,3,3]]))
 
     # Unbind frame buffer
-    glDeleteFramebuffers(np.array([framebuffer]))
-    glDeleteRenderbuffers(1, np.array([renderbuffer]))
-    glDeleteRenderbuffers(1, np.array([depthRenderbuffer]));
-    glBindRenderbuffer(GL_RENDERBUFFER, 0)
-    glBindFramebuffer(GL_FRAMEBUFFER, 0)
+    safeRun(glDeleteFramebuffers, np.array([framebuffer]), fallbacks=(glDeleteFramebuffersEXT))
+    safeRun(glDeleteRenderbuffers, 1, np.array([renderbuffer]), fallbacks=(glDeleteRenderbuffersEXT))
+    safeRun(glDeleteRenderbuffers, 1, np.array([depthRenderbuffer]), fallbacks=(glDeleteRenderbuffersEXT))
+    safeRun(glBindRenderbuffer, GL_RENDERBUFFER, 0, fallbacks=(glBindRenderbufferEXT))
+    safeRun(glBindFramebuffer, GL_FRAMEBUFFER, 0, fallbacks=(glBindFramebufferEXT))
 
     # Restore viewport dimensions to those of the window
     G.windowWidth = oldWidth
     G.windowHeight = oldHeight
-    glPushAttrib(GL_VIEWPORT_BIT)
+    #glPushAttrib(GL_VIEWPORT_BIT)
+    glPopAttrib()
     glViewport(0, 0, oldWidth, oldHeight)
 
     return surface
@@ -1031,12 +1052,12 @@ def draw(productionRender = False):
         else:
             _draw(productionRender)
         return True
-    except StandardError:
+    except Exception:
         log.error('gl.draw', exc_info=True)
         return False
 
 def renderToCanvas():
     if draw():
-        G.canvas.swapBuffers()
+        # G.canvas.swapBuffers()
         # Indicate that picking buffer is out of sync with rendered frame (deferred update)
         markPickingBufferDirty()
