@@ -52,7 +52,7 @@ from getpath import getSysDataPath, getPath, isSubPath, pathToUnicode
 def dummySvgCall():
     """Code which is here just so pyinstaller can discover we need SVG support"""
     dummy = QtSvg.QGraphicsSvgItem("some_svg.svg")
-    
+
 def getLanguageString(text, appendData=None, appendFormat=None):
     """Function to get the translation of a text according to the selected
     language.
@@ -205,11 +205,14 @@ class GroupBox(QtWidgets.QGroupBox, Widget):
     def __str__(self):
         return "%s - %s" % (type(self), str(self.title()))
 
-    def addWidget(self, widget, row = None, column = 0, rowSpan = 1, columnSpan = 1, alignment = QtCore.Qt.Alignment(0)):
+    def addWidget(self, widget, row = None, column = 0, rowSpan = 1, columnSpan = 1, alignment = QtCore.Qt.Alignment(0), tooltip=None):
         # widget.setParent(self)
         if row is None:
             row = self.layout.count()
+        if tooltip is not None:
+            widget.setToolTip(tooltip)
         self.layout.addWidget(widget, row, column, rowSpan, columnSpan, alignment)
+
         widget.show()
         return widget
 
@@ -320,6 +323,9 @@ class _QSlider(QtWidgets.QSlider):
                 return
         super(_QSlider, self).mousePressEvent(event)
 
+#
+# adds a slider to a QGridLayout
+#
 class Slider(QtWidgets.QWidget, Widget):
     _imageCache = {}
     _show_images = False
@@ -332,11 +338,12 @@ class Slider(QtWidgets.QWidget, Widget):
             cls._imageCache[path] = getPixmap(path)
         return cls._imageCache[path]
 
-    def __init__(self, value=0.0, min=0.0, max=1.0, label=None, vertical=False, valueConverter=None, image=None, scale=1000):
+    def __init__(self, value=0.0, min=0.0, max=1.0, label=None, vertical=False, valueConverter=None, image=None, scale=1000, tooltip=None):
         super(Slider, self).__init__()
         #Widget.__init__(self)
         self.text = getLanguageString(label) or ''
-        self.valueConverter = valueConverter
+
+        self.isEditWidgetVisible = False
 
         orient = (QtCore.Qt.Vertical if vertical else QtCore.Qt.Horizontal)
         self.slider = _QSlider(self, orient)
@@ -347,6 +354,8 @@ class Slider(QtWidgets.QWidget, Widget):
         self.min = min
         self.max = max
         self.scale = scale
+        if tooltip is not None:
+            self.slider.setToolTip(tooltip)
         self.slider.setMinimum(0)
         self.slider.setMaximum(self.scale)
         self.slider.setValue(self._f2i(value))
@@ -355,7 +364,6 @@ class Slider(QtWidgets.QWidget, Widget):
         self.slider.valueChanged[int].connect(self._changed)
         self.slider.sliderReleased.connect(self._released)
         self.slider.sliderPressed.connect(self._pressed)
-        self.slider.installEventFilter(self)
 
         self.label = QtWidgets.QLabel(self.text)
         # Decrease vertical gap between label and slider
@@ -366,10 +374,22 @@ class Slider(QtWidgets.QWidget, Widget):
         self.layout.setColumnStretch(0, 1)
         self.layout.setColumnStretch(1, 0)
         self.layout.setColumnStretch(2, 0)
+
+        self.edit = NarrowLineEdit(5)
+        self.edit.returnPressed.connect(self._enter)
+
+        self.units = QtWidgets.QLabel("")
+
+        self.layout.addWidget(self.units, 1, 2, 1, 1)
+        self.layout.addWidget(self.edit, 1, 1, 1, 1)
         self.layout.addWidget(self.label, 1, 0, 1, 1)
         self.layout.addWidget(self.slider, 2, 0, 1, -1)
+
         if not self.text:
             self.label.hide()
+        
+        self.edit.hide()
+        self.units.hide()
 
         if image is not None:
             self.image = QtWidgets.QLabel()
@@ -378,6 +398,14 @@ class Slider(QtWidgets.QWidget, Widget):
         else:
             self.image = None
 
+        # We must define 'self.edit' and 'self.slider' before we call
+        # 'installEventFilter()' on them.
+        self.slider.installEventFilter(self)
+        self.edit.installEventFilter(self)
+
+        # The assignment of 'valueConverter' can only happen after we defined
+        # self.edit and self.units as it hide/show these widgets.
+        self.valueConverter = valueConverter
         self._sync(value)
         self._update_image()
 
@@ -386,24 +414,28 @@ class Slider(QtWidgets.QWidget, Widget):
     def setValueConverter(self, valueConverter):
         self._valueConverter = valueConverter
         if self.valueConverter:
-            self.edit = NarrowLineEdit(5)
-            self.edit.installEventFilter(self)
-            self.edit.returnPressed.connect(self._enter)
-            self.layout.addWidget(self.edit, 1, 1, 1, 1)
             if hasattr(self.valueConverter, 'units'):
-                self.units = QtWidgets.QLabel(self.valueConverter.units)
-                self.layout.addWidget(self.units, 1, 2, 1, 1)
+                self.units.setText(self.valueConverter.units)
+                self.units.show()
             else:
-                self.units = None
+                self.units.hide()
         else:
-            self.edit = None
-            self.units = None
+            self.units.hide()
+        self.setEditWidgetVisibility(self.isEditWidgetVisible)
 
     def getValueConverter(self):
         return self._valueConverter
 
     valueConverter = property(getValueConverter, setValueConverter)
 
+    def setEditWidgetVisibility(self, isVisible):
+        self.isEditWidgetVisible = isVisible
+        if not self.isEditWidgetVisible and self.valueConverter is None:
+            self.edit.hide()
+        else:
+            self.edit.show()
+
+
     def sliderMousePressEvent(self, event):
         """
         Can be used to catch mouse press events from the attached QSlider widget.
@@ -424,6 +456,7 @@ class Slider(QtWidgets.QWidget, Widget):
         newValue = self.fromDisplay(float(text))
         self.setValue(newValue)
         if abs(oldValue - newValue) > 1e-3:
+            self.callEvent('onChanging', newValue)
             self.callEvent('onChange', newValue)
 
     def toDisplay(self, value):
@@ -440,7 +473,7 @@ class Slider(QtWidgets.QWidget, Widget):
 
     def eventFilter(self, object, event):
         if object != self.slider and object != self.edit:
-            return
+            return False
         result = False
         if object == self.edit:
             result = self.edit.eventFilter(object, event)
@@ -490,7 +523,7 @@ class Slider(QtWidgets.QWidget, Widget):
         if self.edit is not None:
             self.edit.setText('%.2f' % self.toDisplay(value))
         if hasattr(self.valueConverter, 'units') and \
-           self.valueConverter.units != str(self.units.text()):
+            self.valueConverter.units != str(self.units.text()):
             self.units.setText(self.valueConverter.units)
 
     def _f2i(self, x):
@@ -609,33 +642,9 @@ class RadioButton(QtWidgets.QRadioButton, ButtonBase):
                 return radio
 
 class ListItem(QtWidgets.QListWidgetItem):
-    def __init__(self, label, tooltip = True):
+    def __init__(self, label):
         super(ListItem, self).__init__(label)
         self.__hasCheckbox = False
-        self.tooltip = tooltip
-
-    def updateTooltip(self):
-        """
-        Attach a mouse-over tooltip for this item if the text is too long to fit
-        the widget.
-        """
-        if not self.tooltip:
-            return
-
-        if not self.listWidget():
-            return
-
-        metrics = QtGui.QFontMetrics(self.font())
-
-        labelWidth = self.listWidget().width()
-        if self.icon():
-            labelWidth -= self.listWidget().iconSize().width() + 10
-            # pad size with 10px to account for margin between icon and text (this is an approximation)
-
-        if metrics.width(self.text)//2 > labelWidth:
-            self.setToolTip(self.text)
-        else:
-            self.setToolTip("")
 
     @property
     def hasCheckbox(self):
@@ -647,10 +656,6 @@ class ListItem(QtWidgets.QListWidgetItem):
     def getUserData(self):
         return self.data(QtCore.Qt.UserRole)
 
-    def setText(self, text):
-        super(ListItem, self).setText(text)
-        self.updateTooltip()
-
     @property
     def text(self):
         return str(super(ListItem, self).text())
@@ -975,7 +980,7 @@ class ProgressBar(QtWidgets.QProgressBar, Widget):
     def setProgress(self, progress):
         min_ = self.minimum()
         max_ = self.maximum()
-        self.setValue(min_ + progress * (max_ - min_))
+        self.setValue(round(min_ + progress * (max_ - min_)))
 
 class ShortcutEdit(QtWidgets.QLabel, Widget):
     def __init__(self, shortcut):
@@ -1230,8 +1235,10 @@ class AboutBoxScrollbars(QtWidgets.QDialog):
             re_match_urls = re.compile(r"""((?:[a-z][\w-]+:(?:/{1,3}|[a-z0-9%])|www\d{0,3}[.]|[a-z0-9.\-]+[.‌​][a-z]{2,4}/)(?:[^\s()<>]+|(([^\s()<>]+|(([^\s()<>]+)))*))+(?:(([^\s()<>]+|(‌​([^\s()<>]+)))*)|[^\s`!()[]{};:'".,<>?«»“”‘’]))""", re.DOTALL)
             return re_match_urls.sub(lambda x: '<a href="%(url)s" style="color: #ffa02f;">%(url)s</a>' % dict(url=str(x.group())), text)
 
-        if sys.platform.startswith('darwin'):
-            self.setWindowFlags(QtCore.Qt.WindowTitleHint | QtCore.Qt.WindowSystemMenuHint)
+        # Causes whole app to hang
+        # if sys.platform.startswith('darwin'):
+        #     self.setWindowFlags(QtCore.Qt.WindowTitleHint | QtCore.Qt.WindowSystemMenuHint)
+
         # Grab window icon of parent
         icon = self.windowIcon()
         size = icon.actualSize(QtCore.QSize(64, 64))
@@ -1308,7 +1315,7 @@ class AboutBoxScrollbars(QtWidgets.QDialog):
         self.setModal(True)
         self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
 
-        size = QtCore.QSize(min(parent.size().width(), width + 60), 0.8 * parent.size().height())
+        size = QtCore.QSize(min(parent.size().width(), width + 60), int(0.8 * parent.size().height()))
         self.resize(size)
 
 
@@ -1688,7 +1695,7 @@ class VScrollLayout(QtWidgets.QLayout):
             rect.setHeight(max(rect.height(), size.height()))
 
         # log.debug('VScrollLayout.setGeometry(child): %d %d %d %d', rect.x(), rect.y(), rect.width(), rect.height())
-        self._child.setGeometry(rect)
+        self._child.widget().setGeometry(rect)
 
     def expandingDirections(self):
         if self._child is None:
@@ -2204,6 +2211,7 @@ class ZoomableImageView(QtWidgets.QScrollArea, Widget):
         self.workingWidth = None
         self.ratio = 1.0
         self.minratio = 0.1
+        self.mdown = None
 
     def setImage(self, img):
         pixmap = getPixmap(img)
@@ -2260,15 +2268,30 @@ class ZoomableImageView(QtWidgets.QScrollArea, Widget):
 
     def mouseMoveEvent(self, event):
         if event.buttons() & QtCore.Qt.RightButton:
-            self.wheelEvent(QtGui.QWheelEvent(event.pos(),
-                                              10 * (event.pos().y() - self.mdown.y()),
-                                              event.buttons(), event.modifiers()), False)
+            angleDeltay = 10 * (event.pos().y() - self.mdown.y())
+            displace = False
+            ratbef = self.ratio
+            if G.app.getSetting('invertMouseWheel'):
+                deltay = angleDeltay
+            else:
+                deltay = -angleDeltay
+            factor = 1 - deltay * 0.0007
+            self.ratio *= factor
+            if self.ratio > 1.0:
+                self.ratio = 1.0
+            if self.ratio < self.minratio:
+                self.ratio = self.minratio
+            dr = 2 * abs(self.ratio - ratbef) if displace else 0
+            self.refreshImage(True,
+                              (dr * (event.x() - self.width() / 2),
+                               dr * (event.y() - self.height() / 2)))
             self.mdown = event.pos()
         else:
-            self.horizontalScrollBar().setValue(
-                self.horizontalScrollBar().value() + 2*(self.mdown.x() - event.pos().x()))
-            self.verticalScrollBar().setValue(
-                self.verticalScrollBar().value() + 2*(self.mdown.y() - event.pos().y()))
+            if self.mdown is not None:
+                self.horizontalScrollBar().setValue(
+                    self.horizontalScrollBar().value() + 2 * (self.mdown.x() - event.pos().x()))
+                self.verticalScrollBar().setValue(
+                    self.verticalScrollBar().value() + 2 * (self.mdown.y() - event.pos().y()))
             self.mdown = event.pos()
             self.refreshImage()
 
