@@ -175,24 +175,25 @@ g_mouse_pos = None
 gg_mouse_pos = None
 g_mousewheel_t = None
 
-class Canvas(QtOpenGL.QGLWidget):
+class Canvas(QtWidgets.QOpenGLWidget):
     def __init__(self, parent, app):
         self.app = app
         self.blockRedraw = False
-        format = QtOpenGL.QGLFormat()
-        format.setAlpha(True)
+        format = QtGui.QSurfaceFormat()
+        format.setAlphaBufferSize(8)
         format.setDepthBufferSize(24)
-        if not G.preStartupSettings["noSampleBuffers"]:
-            format.setSampleBuffers(True)
-            format.setSamples(4)
-        super(Canvas, self).__init__(format, parent)
+        format.setSwapBehavior(QtGui.QSurfaceFormat.DoubleBuffer)
+        #if not G.preStartupSettings["noSampleBuffers"]:
+        #    format.setSamples(4)
+        format.setSamples(0)
+        super(Canvas, self).__init__(parent)
+        self.setFormat(format)
         self.create()
 
     def create(self):
         G.canvas = self
         self.setFocusPolicy(QtCore.Qt.TabFocus)
         self.setFocus()
-        self.setAutoBufferSwap(False)
         self.setAutoFillBackground(False)
         self.setAttribute(QtCore.Qt.WA_NativeWindow)
         self.setAttribute(QtCore.Qt.WA_NoSystemBackground, False)
@@ -215,9 +216,11 @@ class Canvas(QtOpenGL.QGLWidget):
         return (relPos.x(), relPos.y())
 
     def mousePressEvent(self, ev):
+        self.makeCurrent()
         self.mouseUpDownEvent(ev, "onMouseDownCallback")
 
     def mouseReleaseEvent(self, ev):
+        self.makeCurrent()
         self.mouseUpDownEvent(ev, "onMouseUpCallback")
 
     def mouseUpDownEvent(self, ev, direction):
@@ -229,6 +232,7 @@ class Canvas(QtOpenGL.QGLWidget):
 
         gg_mouse_pos = x, y
 
+        self.makeCurrent()
         G.app.callEvent(direction, events3d.MouseEvent(b, x, y))
 
         # Update screen
@@ -249,6 +253,7 @@ class Canvas(QtOpenGL.QGLWidget):
             x = y = None
 
         b = 1 if d > 0 else -1
+        self.makeCurrent()
         G.app.callEvent('onMouseWheelCallback', events3d.MouseWheelEvent(b, x, y))
 
         if g_mousewheel_t is None or t - g_mousewheel_t > MOUSEWHEEL_PICK_TIMEOUT:
@@ -286,6 +291,7 @@ class Canvas(QtOpenGL.QGLWidget):
 
         buttons = int(G.app.mouseButtons())
 
+        self.makeCurrent()
         G.app.callEvent('onMouseMovedCallback', events3d.MouseEvent(buttons, x, y, xrel, yrel))
 
         if buttons:
@@ -354,7 +360,7 @@ class VLayout(QtWidgets.QLayout):
         return width, y
 
     def sizeHint(self):
-        width, height = self._doLayout(0, 0, 1e9, 1e9, False)
+        width, height = self._doLayout(0, 0, int(1e9), int(1e9), False)
         return QtCore.QSize(width, height)
 
     def maximumSize(self):
@@ -584,8 +590,7 @@ class Frame(QtWidgets.QMainWindow):
             state.add('fullscreen')
         if stateflags & QtCore.Qt.WindowActive:
             state.add('active')
-        if not (stateflags &
-            (QtCore.Qt.WindowMaximized | QtCore.Qt.WindowFullScreen)):
+        if not(stateflags & QtCore.Qt.WindowMaximized) and not(stateflags & QtCore.Qt.WindowFullScreen):
             state.add('normal geometry')
             if not stateflags & QtCore.Qt.WindowMinimized:
                 state.add('normal')
