@@ -14,7 +14,7 @@ MakeHuman python entry-point.
 
 **Copyright(c):**      MakeHuman Team 2001-2020
 
-**Licensing:**         AGPL3 
+**Licensing:**         AGPL3
 
     This file is part of MakeHuman Community (www.makehumancommunity.org).
 
@@ -42,12 +42,12 @@ import os
 import re
 import subprocess
 
-from PyQt5 import QtCore
+#from PyQt5 import QtCore
 
 ## Version information #########################################################
-__version__ = "1.2.0"                   # Major, minor and patch version number
+__version__ = "1.3.0"                   # Major, minor and patch version number
 release = False                         # False for nightly
-versionSub = "final"                    # Short version description
+versionSub = "alpha"                    # Short version description
 meshVersion = "hm08"                    # Version identifier of the basemesh
 ################################################################################
 
@@ -141,9 +141,16 @@ def set_sys_path():
     #[BAL 07/11/2013] make sure we're in the right directory
     if not sys.platform.startswith('darwin'): # Causes issues with py2app builds on MAC
         os.chdir(getCwd())
-    syspath = ["./", "./lib", "./apps", "./shared", "./apps/gui","./core"]
-    syspath.extend(sys.path)
-    sys.path = syspath
+        syspath = ["./", "./lib", "./apps", "./shared", "./apps/gui","./core"]
+        syspath.extend(sys.path)
+        sys.path = syspath
+    else:
+        data_path = "../Resources/makehuman"
+        if(os.path.isdir(data_path)):
+            os.chdir(data_path)
+        syspath = ["./lib", "./apps", "./shared", "./apps/gui", "./core", "../lib", "../"]
+        syspath.extend(sys.path)
+        sys.path = syspath
 
     if isBuild():
         # Make sure we load packaged DLLs instead of those present on the system
@@ -222,11 +229,11 @@ def parse_arguments():
     parser.add_argument('-v', '--version', action='version', version=getVersionStr())
     parser.add_argument("--license", action="store_true", help="Show full copyright notice and software license")
     parser.add_argument("--noshaders", action="store_true", help="disable shaders")
-    parser.add_argument("--nomultisampling", action="store_true", help="disable multisampling (used for anti-aliasing and alpha-to-coverage transparency rendering)")
+    parser.add_argument("--multisampling", action="store_true", help="enable multisampling (used for anti-aliasing and alpha-to-coverage transparency rendering)")
     parser.add_argument("--debugopengl", action="store_true", help="enable OpenGL error checking and logging (slow)")
     parser.add_argument("--fullloggingopengl", action="store_true", help="log all OpenGL calls (very slow)")
     parser.add_argument("--debugnumpy", action="store_true", help="enable numpy runtime error messages")
-    
+
     if not isRelease():
         parser.add_argument("-t", "--runtests", action="store_true", help="run test suite (for developers)")
 
@@ -248,7 +255,7 @@ This program comes with ABSOLUTELY NO WARRANTY.
 This is free software, and you are welcome to redistribute it
 under certain conditions. For details use the option --license"""
 
-    return """Makehuman is a completely free, open source, innovative and 
+    return """Makehuman is a completely free, open source, innovative and
 professional software for the modelling of 3-Dimensional humanoid characters
 Copyright (C) 2001-2020  www.makehumancommunity.org
 
@@ -283,12 +290,12 @@ For further help, have a look in the community wiki at:
 
     http://www.makehumancommunity.org/wiki/Main_Page
 
-If you have other questions or need support, feel free to ask on our 
+If you have other questions or need support, feel free to ask on our
 forums at:
 
     http://www.makehumancommunity.org/forum/
 
-The forums is also where you can contact the MakeHuman team. 
+The forums is also where you can contact the MakeHuman team.
 
 Bugs can be reported on the project's bug tracker(s):
 
@@ -380,7 +387,7 @@ Homepage: %s""" % (self.author, self.license, self.copyright, self.homepage)
         if len(words) < 1:
             return
 
-        key = words[0]
+        key = words[0].rstrip(":")
         value = " ".join(words[1:])
 
         self.setProperty(key,value)
@@ -408,7 +415,7 @@ Homepage: %s""" % (self.author, self.license, self.copyright, self.homepage)
                 l_key = index[i]
                 l_val = index[i+1]
 
-                key = text[last:last+l_key].tostring()
+                key = str(text[last:last+l_key].tostring(), 'utf8')
                 val = str(text[last+l_key:last+l_key+l_val].tostring(), 'utf8')
                 stringDict[key] = val
 
@@ -436,7 +443,7 @@ def getAssetLicense(properties=None):
 
 def _wordwrap(text, chars_per_line=80):
     """Split the lines of a text between whitespaces when a line length exceeds
-    the specified number of characters. Newlines already present in text are 
+    the specified number of characters. Newlines already present in text are
     kept.
     """
     text_ = text.split('\n')
@@ -465,15 +472,6 @@ def _wordwrap(text, chars_per_line=80):
         text.pop()
     return '\n'.join(text)
 
-def getCredits(richtext=False):
-    # TODO print contributors.txt
-    if richtext:
-        result = '<h2>MakeHuman credits</h2>'
-    else:
-        result = ''
-    return result + '''The list of people that made this software can be found at our website at 
-http://www.makehumancommunity.org/halloffame'''
-
 def getSoftwareLicense(richtext=False):
     import getpath
     from io import open
@@ -518,7 +516,7 @@ def getThirdPartyLicenses(richtext=False):
         result = '<h2>Third-party licenses</h2>'
     else:
         result = ""
-    result += """MakeHuman includes a number of third part software components, which have 
+    result += """MakeHuman includes a number of third part software components, which have
 their own respective licenses. We express our gratitude to the developers of
 those libraries, without which MakeHuman would not have been made possible.
 Here follows a list of the third-party open source libraries that MakeHuman
@@ -550,6 +548,30 @@ makes use of.\n"""
 
     return result
 
+def getCredits(richtext=False):
+    import getpath
+
+    def _error(text):
+        if richtext:
+            return '<span style="color: red;">%s</span>' % text
+        else:
+            return text
+
+    def _block(text):
+        if richtext:
+            return '%s<hr style="border: 1px solid #ffa02f;">' % text
+        else:
+            return text
+
+    license_folder = getpath.getSysPath('licenses')
+    cfile = os.path.join(license_folder, "credits.txt")
+    if not os.path.isfile(cfile):
+        return ( _error("Error: Credits file %s is not found, this is an incomplete MakeHuman distribution!" % cfile))
+    with open(cfile, encoding='utf-8') as f:
+        text = f.read()
+
+    text = _wordwrap(text)
+    return( _block(text))
 
 def main():
     print(getCopyrightMessage(short=True) + "\n")
