@@ -288,10 +288,9 @@ def fbx_data_mesh_element(objectsParent, key, id, properties, coord, fvert, vnor
     import numpy as np
 
     if vertsperface == 3:
-        fvert_ = np.zeros((len(fvert),3), dtype=np.float32)
+        fvert_ = np.zeros((len(fvert),3), dtype=np.int32)
         fvert_[:,:3] = fvert[:,:3]
-        for fv in fvert_:
-            fv[2] = -1-fv[2]
+        fvert_[:,2] = ~fvert_[:,2]
     else:
         fvert_ = fvert.copy()
         fvert_[:,3] = ~fvert_[:,3]
@@ -318,7 +317,7 @@ def fbx_data_mesh_element(objectsParent, key, id, properties, coord, fvert, vnor
 
     elem_data_single_float64_array(lay_nor, b"Normals", t_ln)
 
-    elem_data_single_int32_array(lay_nor, b"NormalsIndex", fvert.reshape(-1))
+    elem_data_single_int32_array(lay_nor, b"NormalsIndex", fvert_.astype(np.int32).reshape(-1))
     del t_ln
 
     # TODO export tangents
