@@ -1,20 +1,20 @@
-#!/usr/bin/python2.7
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 """
 **Project Name:**      MakeHuman
 
-**Product Home Page:** http://www.makehuman.org/
+**Product Home Page:** http://www.makehumancommunity.org/
 
-**Code Home Page:**    https://bitbucket.org/MakeHuman/makehuman/
+**Github Code Home Page:**    https://github.com/makehumancommunity/
 
 **Authors:**           Jonas Hauquier
 
-**Copyright(c):**      MakeHuman Team 2001-2017
+**Copyright(c):**      MakeHuman Team 2001-2020
 
 **Licensing:**         AGPL3
 
-    This file is part of MakeHuman (www.makehuman.org).
+    This file is part of MakeHuman Community (www.makehumancommunity.org).
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -143,25 +143,25 @@ class Color(object):
 
     # Scalar operators work both with iterables as well as single values
     def __mul__(self, other):
-        if isinstance(other, (int, float, long, bool)):
+        if isinstance(other, (int, float, bool)):
             return type(self)(self.r * other, self.g * other, self.b * other)
         else:
             return type(self)(self.r * other[0], self.g * other[1], self.b * other[2])
 
     def __rmul__(self, other):
-        if isinstance(other, (int, float, long, bool)):
+        if isinstance(other, (int, float, bool)):
             return type(self)(other * self.r, other * self.g, other * self.b)
         else:
             return type(self)(other[0] * self.r, other[1] * self.g, other[2] * self.b)
 
     def __div__(self, other):
-        if isinstance(other, (int, float, long, bool)):
+        if isinstance(other, (int, float, bool)):
             return type(self)(self.r / other, self.g / other, self.b / other)
         else:
             return type(self)(self.r / other[0], self.g / other[1], self.b / other[2])
 
     def __rdiv__(self, other):
-        if isinstance(other, (int, float, long, bool)):
+        if isinstance(other, (int, float, bool)):
             return type(self)(other / self.r, other / self.g, other / self.b)
         else:
             return type(self)(other[0] / self.r, other[1] / self.g, other[2] / self.b)
@@ -205,6 +205,9 @@ class Material(object):
         self._specularColor = Color(1.0, 1.0, 1.0)
         self._shininess = 0.2
         self._emissiveColor = Color()
+        self._viewPortColor = Color()
+        self._viewPortAlpha = 1.0
+        self._hasViewPortColor = False
 
         self._opacity = 1.0
         self._translucency = 0.0
@@ -276,6 +279,9 @@ class Material(object):
         self._specularColor.copyFrom(material.specularColor)
         self._shininess = material.shininess
         self._emissiveColor.copyFrom(material.emissiveColor)
+        self._viewPortColor.copyFrom(material.viewPortColor)
+        self._viewPortAlpha = material.viewPortAlpha
+        self._hasViewPortColor = material._hasViewPortColor
 
         self._opacity = material.opacity
         self._translucency = material.translucency
@@ -327,13 +333,12 @@ class Material(object):
         """
         Parse .mhmat file and set as the properties of this material.
         """
-        from codecs import open
         log.debug("Loading material from file %s", filename)
         try:
-            f = open(filename, "rU", encoding="utf-8")
+            f = open(filename, "r", encoding="utf-8")
         except:
             f = None
-        if f == None:
+        if f is None:
             log.error("Failed to load material from file %s.", filename)
             return
 
@@ -379,6 +384,12 @@ class Material(object):
                 self._shininess = max(0.0, min(1.0, float(words[1])))
             elif words[0] == "emissiveColor":
                 self._emissiveColor.copyFrom([float(w) for w in words[1:4]])
+            elif words[0] == "viewPortColor":
+                self._viewPortColor.copyFrom([float(w) for w in words[1:4]])
+                self._hasViewPortColor = True
+            elif words[0] == "viewPortAlpha":
+                self._viewPortAlpha = max(0.0, min(1.0, float(words[1])))
+                self._hasViewPortColor = True
             elif words[0] == "opacity":
                 self._opacity = max(0.0, min(1.0, float(words[1])))
             elif words[0] == "translucency":
@@ -498,13 +509,12 @@ class Material(object):
             return formatPath(filename)
 
     def toFile(self, filename, comments = []):
-        from codecs import open
 
         try:
             f = open(filename, 'w', encoding='utf-8')
         except:
             f = None
-        if f == None:
+        if f is None:
             log.error("Failed to open material file %s for writing.", filename)
             return
 
@@ -580,7 +590,7 @@ class Material(object):
 
         hasShaderParam = False
         global _materialShaderParams
-        for name, param in self.shaderParameters.items():
+        for name, param in list(self.shaderParameters.items()):
             if name not in _materialShaderParams:
                 hasShaderParam = True
                 import image
@@ -589,7 +599,7 @@ class Material(object):
                         f.write("shaderParam %s %s\n" % (name, self._texPath(param.sourcePath, filedir)) )
                 elif isinstance(param, list):
                     f.write("shaderParam %s %s\n" % (name, " ".join([str(p) for p in param])) )
-                elif isinstance(param, basestring) and not isNumeric(param):
+                elif isinstance(param, str) and not isNumeric(param):
                     # Assume param is a path
                     f.write("shaderParam %s %s\n" % (name, self._texPath(param, filedir)) )
                 else:
@@ -604,7 +614,7 @@ class Material(object):
                 f.write("shaderDefine %s\n" % define)
         if hasShaderDefine: f.write('\n')
 
-        for name, value in self.shaderConfig.items():
+        for name, value in list(self.shaderConfig.items()):
             f.write("shaderConfig %s %s\n" % (name, value) )
 
         f.close()
@@ -685,6 +695,30 @@ class Material(object):
 
     shininess = property(getShininess, setShininess)
 
+    def getViewPortColor(self):
+        return self._viewPortColor
+
+    def setViewPortColor(self, color):
+        self._viewPortColor.copyFrom(color)
+        self._hasViewPortColor = True
+
+    viewPortColor = property(getViewPortColor, setViewPortColor)
+
+    def getViewPortAlpha(self):
+        return self._viewPortAlpha
+
+    def setViewPortAlpha(self, alpha):
+        self._viewPortAlpha = max(0.0, min(1.0, alpha))
+        self._hasViewPortColor = True
+
+    viewPortAlpha = property(getViewPortAlpha, setViewPortAlpha)
+
+    def usesViewPortColor(self):
+        return self._hasViewPortColor
+
+    def enableViewPortColor(self, b=True):
+        self._hasViewPortColor = b
+
 
     def getSpecularIntensity(self):
         """
@@ -993,7 +1027,7 @@ class Material(object):
 
     def getShaderObj(self):
         import sys
-        if 'shader' not in sys.modules.keys():
+        if 'shader' not in list(sys.modules.keys()):
             # Don't import shader module in application if it is not loaded yet
             # Avoid unneeded dependency on OpenGL/shader modules
             return None
@@ -1060,7 +1094,7 @@ class Material(object):
 
         if isinstance(value, list):
             value = [float(v) for v in value]
-        elif isinstance(value, basestring):
+        elif isinstance(value, str):
             if isNumeric(value):
                 value = float(value)
             else:
@@ -1135,7 +1169,7 @@ class Material(object):
 
 
     def _getTexture(self, texture):
-        if isinstance(texture, basestring):
+        if isinstance(texture, str):
             return getFilePath(texture, self.filepath)
         else:
             return texture
@@ -1161,13 +1195,13 @@ class Material(object):
         if includeUniforms:
             uniformSamplers = OrderedDict()
             usedByShader = self.shaderUniforms
-            for name, param in self.shaderParameters.items():
+            for name, param in list(self.shaderParameters.items()):
                 if name not in _materialShaderParams and \
                    (includeUnused or name in usedByShader):
                     import image
                     if isinstance(param, image.Image) and includeInMemory:
                         uniformSamplers[name] = param
-                    elif isinstance(param, basestring) and not isNumeric(param):
+                    elif isinstance(param, str) and not isNumeric(param):
                         # Assume param is a path
                         uniformSamplers[name] = param
             result.update(uniformSamplers)
@@ -1338,7 +1372,7 @@ class Material(object):
                 del textures[t]
 
         progress = Progress(len(textures))
-        for tName,tPath in textures.items():
+        for tName,tPath in list(textures.items()):
             progress.step("Exporting texture %s", tName)
             import image
             if isinstance(tPath, image.Image):
@@ -1382,7 +1416,7 @@ def getSkinBlender():
     return _autoSkinBlender
 
 def getFilePath(filename, folder = None):
-    if not filename or not isinstance(filename, basestring):
+    if not filename or not isinstance(filename, str):
         return filename
 
     searchPaths = []
@@ -1444,28 +1478,25 @@ class UVMap:
 
 
 def loadUvObjFile(filepath):
-    from codecs import open
-    fp = open(filepath, "rU", encoding="utf-8")
-    uvs = []
-    fuvs = []
-    for line in fp:
-        words = line.split()
-        if len(words) == 0:
-            continue
-        elif words[0] == "vt":
-            uvs.append((float(words[1]), float(words[2])))
-        elif words[0] == "f":
-            fuvs.append( [(int(word.split("/")[1]) - 1) for word in words[1:]] )
-    fp.close()
+    with open(filepath, "r", encoding="utf-8") as fp:
+        uvs = []
+        fuvs = []
+        for line in fp:
+            words = line.split()
+            if len(words) == 0:
+                continue
+            elif words[0] == "vt":
+                uvs.append((float(words[1]), float(words[2])))
+            elif words[0] == "f":
+                fuvs.append( [(int(word.split("/")[1]) - 1) for word in words[1:]] )
     return uvs,fuvs
 
 def peekMetadata(filename):
-    from codecs import open
     try:
-        f = open(filename, "rU", encoding="utf-8")
+        f = open(filename, "r", encoding="utf-8")
     except:
         f = None
-    if f == None:
+    if f is None:
         log.error("Failed to load metadata from material file %s.", filename)
         return
 
@@ -1488,6 +1519,7 @@ def peekMetadata(filename):
             description = " ".join(words[1:])
         else:
             pass
+    f.close()
 
     if description is None:
         description = "%s material" % name
