@@ -106,6 +106,7 @@ class Proxy:
         self.uvLayers = {}  # TODO what is this used for?
 
         self.material = material.Material(self.name)
+        self._backUpMaterial = None
 
         self._obj_file = None
         self._vertexBoneWeights_file = None
@@ -374,7 +375,7 @@ def loadProxy(human, path, type="Clothes"):
 
 def loadTextProxy(human, filepath, type="Clothes"):
     try:
-        fp = open(filepath, "r", encoding="utf-8")
+        fp = open(filepath, "r", encoding="utf-8", errors='ignore')
     except IOError:
         log.error("*** Cannot open %s", filepath)
         return None
@@ -408,7 +409,7 @@ def loadTextProxy(human, filepath, type="Clothes"):
             proxy.uuid = " ".join(words[1:])
         elif key == 'description':
             proxy.description = " ".join(words[1:])
-        elif key in ['author', 'license', 'homepage']:
+        elif key in ['author', 'license', 'homepage', 'author:', 'license:']:
             proxy.license.updateFromComment(words)
         elif key == 'tag':
             proxy.tags.append( " ".join(words[1:]).lower() )
@@ -1019,7 +1020,7 @@ def peekMetadata(proxyFilePath, proxyType=None):
             log.warning("Problem loading metadata from binary proxy, trying ASCII file: %s", e, exc_info=showTrace)
 
     # ASCII proxy file
-    with open(proxyFilePath, 'r', encoding="utf-8") as fp:
+    with open(proxyFilePath, 'r', encoding="utf-8", errors='ignore') as fp:
         uuid = None
         tags = set()
         for line in fp:
